#
# spec file for package hylafax+
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global faxspool    %{_localstatedir}/spool/hylafax
%define lib_version %(echo %{version} | tr \. _)
Name:           hylafax+
Version:        5.5.9
Release:        lp150.4.1
Summary:        An enterprise-strength fax server
License:        BSD-3-Clause
Group:          Productivity/Telephony/Servers
Url:            http://hylafax.sourceforge.net
Source0:        http://downloads.sourceforge.net/hylafax/hylafax-%{version}.tar.gz
Source2:        hylafax+_daily.cron
Source3:        hylafax+_hourly.cron
Source4:        hylafax-hfaxd.service
Source5:        hylafax-faxq.service
Source6:        hylafax-faxgetty-ttyS0.service
Source7:        README.SUSE
Source8:        sendonly.conf
#Fix for language-dependent notification
Patch0:         notification.diff
#Fix for language-dependent notification
BuildRequires:  gcc-c++
BuildRequires:  ghostscript
BuildRequires:  libjbig-devel
BuildRequires:  libjpeg-devel
BuildRequires:  openldap2-devel
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(zlib)
Requires:       cron
Requires:       gawk
Requires:       ghostscript
Requires:       ghostscript-fonts
# Server checks for existence of sendfax
Requires:       hylafax+-client
Requires:       mailx
Requires:       sharutils
Requires:       tiff
%if 0%{?suse_version} >= 1500
Requires(pre):  group(uucp)
Requires(pre):  user(uucp)
%else
Requires(pre):  aaa_base
%endif
Conflicts:      hylafax < 30.0.0
Conflicts:      mgetty-sendfax
Provides:       hylafax = 30.0.0
%{?systemd_requires}

%description
HylaFAX(tm) is an enterprise-strength fax server supporting
Class 1 and 2 fax modems on UNIX systems. It provides spooling
services and numerous supporting fax management tools.
The fax clients may reside on machines different from the server
and client implementations exist for a number of platforms including
windows.

%package -n libfaxutil%{lib_version}
Summary:        Runtime Library needed by both server and client
Group:          System/Libraries

%description -n libfaxutil%{lib_version}
This runtime lib is needed by both the server and the client.

%package -n hylafax+-client
Summary:        Linux client package for the Hylafax server
Group:          Hardware/Fax
Conflicts:      hylafax-client < 30.0.0
Conflicts:      sendfax
Provides:       hylafax-client = 30.0.0

%description -n hylafax+-client
This is linux client part of the very powerful Hylafax fax server. If
you already run the Hylafax fax server on an other machine at your
network, you can use this package to access the server.

%prep
%setup -q -n hylafax-%{version}
cp %{SOURCE7} .
cp %{SOURCE8} .
#Fix for language-dependent notification
%patch0 -p1

%build
# - Can't use the configure macro because HylaFAX configure script does
#   not understand the config options used by that macro
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" \
STRIP=':' \
./configure \
        --with-DIR_BIN=%{_bindir} \
        --with-DIR_SBIN=%{_sbindir} \
        --with-DIR_LIB=%{_libdir} \
        --with-DIR_LIBEXEC=%{_sbindir} \
        --with-DIR_LIBDATA=%{_sysconfdir}/hylafax \
        --with-DIR_LOCKS=%{_localstatedir}/lock \
        --with-LIBDIR=%{_libdir} \
        --with-TIFFBIN=%{_bindir} \
        --with-DIR_MAN=%{_mandir} \
        --with-PATH_GSRIP=%{_bindir}/gs \
        --with-TIFFINC=-L%{_includedir} \
        --with-LIBTIFF="-ltiff" \
        --with-DIR_SPOOL=%{faxspool} \
        --with-AFM=no \
        --with-AWK=%{_bindir}/gawk \
        --with-PATH_VGETTY=/sbin/vgetty \
        --with-PATH_GETTY=/sbin/mgetty \
        --with-PAGESIZE=A4 \
        --with-PATH_DPSRIP=%{faxspool}/bin/ps2fax \
        --with-PATH_IMPRIP="" \
        --with-SYSVINIT=%{_initddir}/hylafax+ \
        --with-INTERACTIVE=no

# can't use _smp_mflags because it breaks libfaxutil dso building
make -j1

%install
# install: make some dirs...
mkdir -p -m 755 %{buildroot}%{_sysconfdir}/{cron.daily,cron.hourly}
mkdir -p -m 755 %{buildroot}%{_sysconfdir}/hylafax
mkdir -p -m 755 %{buildroot}%{_unitdir}
mkdir -p -m 755 %{buildroot}%{_initrddir}
mkdir -p -m 755 %{buildroot}%{_bindir}
mkdir -p -m 755 %{buildroot}%{_sbindir}
mkdir -p -m 755 %{buildroot}%{_libdir}
mkdir -p -m 755 %{buildroot}%{_mandir}
mkdir -p -m 755 %{buildroot}%{faxspool}/config

# install: binaries and man pages
# FAXUSER, FAXGROUP, SYSUSER and SYSGROUP are set to the current user to
# avoid warnings about chown/chgrp if the user building the SRPM is not root;
# they are set to the correct values with the RPM attr macro
make install -e \
        FAXUSER=`id -u` \
        FAXGROUP=`id -g` \
        SYSUSER=`id -u` \
        SYSGROUP=`id -g` \
        BIN=%{buildroot}%{_bindir} \
        SBIN=%{buildroot}%{_sbindir} \
        LIBDIR=%{buildroot}%{_libdir} \
        LIBDATA=%{buildroot}%{_sysconfdir}/hylafax \
        LIBEXEC=%{buildroot}%{_sbindir} \
        SPOOL=%{buildroot}%{faxspool} \
        MAN=%{buildroot}%{_mandir} \
        INSTALL_ROOT=%{buildroot}

install -p -m 644 %{SOURCE4} %{buildroot}%{_unitdir}/hylafax-hfaxd.service
install -p -m 644 %{SOURCE5} %{buildroot}%{_unitdir}/hylafax-faxq.service
install -p -m 644 %{SOURCE6} %{buildroot}%{_unitdir}/hylafax-faxgetty-ttyS0.service
install -p -m 755 %{SOURCE2} %{buildroot}%{_sysconfdir}/cron.daily/hylafax
install -p -m 755 %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.hourly/hylafax

for lnk in hylafax-hfaxd hylafax-faxgetty-ttyS0 hylafax-faxq; do
    ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rc$lnk
done
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rchylafax

# not being executable is rather unconvenient
chmod +x %{buildroot}%{_sbindir}/edit-faxcover

# Prepare docdir by removing non-doc files
# Remove files that are not needed on Linux
rm -f %{buildroot}%{_sbindir}/{faxsetup.irix,faxsetup.bsdi}
rm -f %{buildroot}%{faxspool}/bin/{ps2fax.imp,ps2fax.dps}

rm -f %{buildroot}%{faxspool}/COPYRIGHT

%pre
%service_add_pre hylafax-faxq.service
%service_add_pre hylafax-faxgetty-ttyS0.service
%service_add_pre hylafax-hfaxd.service

%post
/sbin/ldconfig
%service_add_post hylafax-faxq.service
%service_add_post hylafax-faxgetty-ttyS0.service
%service_add_post hylafax-hfaxd.service

%preun
%service_del_preun hylafax-faxq.service
%service_del_preun hylafax-faxgetty-ttyS0.service
%service_del_preun hylafax-hfaxd.service

%postun
/sbin/ldconfig
%service_del_postun hylafax-faxq.service
%service_del_postun hylafax-faxgetty-ttyS0.service
%service_del_postun hylafax-hfaxd.service

%post -n libfaxutil%{lib_version} -p /sbin/ldconfig
%postun -n libfaxutil%{lib_version} -p /sbin/ldconfig

%files
%{_unitdir}/hylafax-hfaxd.service
%{_unitdir}/hylafax-faxq.service
%{_unitdir}/hylafax-faxgetty-ttyS0.service
%{_sbindir}/rchylafax-faxgetty-ttyS0
%{_sbindir}/rchylafax-faxq
%{_sbindir}/rchylafax-hfaxd
%{_sbindir}/rchylafax
%defattr(-,uucp,uucp,-)
%doc CHANGES CONTRIBUTORS COPYRIGHT README TODO VERSION README.SUSE sendonly.conf
%exclude %{_libdir}/libfaxutil*
%{_libdir}/libfax*
%{_mandir}/man5/hylafax-config.5f%{ext_man}
%{_mandir}/man5/doneq.5f%{ext_man}
%{_mandir}/man5/dialrules.5f%{ext_man}
%{_mandir}/man5/hosts.hfaxd.5f%{ext_man}
%{_mandir}/man5/hylafax-server.5f%{ext_man}
%{_mandir}/man5/hylafax-info.5f%{ext_man}
%{_mandir}/man5/hylafax-log.5f%{ext_man}
%{_mandir}/man5/pagermap.5f%{ext_man}
%{_mandir}/man5/pagesizes.5f%{ext_man}
%{_mandir}/man5/recvq.5f%{ext_man}
%{_mandir}/man5/sendq.5f%{ext_man}
%{_mandir}/man5/hylafax-shutdown.5f%{ext_man}
%{_mandir}/man5/status.5f%{ext_man}
%{_mandir}/man5/tsi.5f%{ext_man}
%{_mandir}/man5/typerules.5f%{ext_man}
%{_mandir}/man5/xferfaxlog.5f%{ext_man}
%{_mandir}/man8/choptest.8c%{ext_man}
%{_mandir}/man8/cqtest.8c%{ext_man}
%{_mandir}/man8/dialtest.8c%{ext_man}
%{_mandir}/man8/faxabort.8c%{ext_man}
%{_mandir}/man8/faxaddmodem.8c%{ext_man}
%{_mandir}/man8/faxadduser.8c%{ext_man}
%{_mandir}/man8/faxanswer.8c%{ext_man}
%{_mandir}/man8/faxconfig.8c%{ext_man}
%{_mandir}/man8/faxcron.8c%{ext_man}
%{_mandir}/man8/faxdeluser.8c%{ext_man}
%{_mandir}/man8/faxgetty.8c%{ext_man}
%{_mandir}/man8/faxinfo.8c%{ext_man}
%{_mandir}/man8/faxlock.8c%{ext_man}
%{_mandir}/man8/faxmodem.8c%{ext_man}
%{_mandir}/man8/faxq.8c%{ext_man}
%{_mandir}/man8/faxqclean.8c%{ext_man}
%{_mandir}/man8/faxquit.8c%{ext_man}
%{_mandir}/man8/faxrcvd.8c%{ext_man}
%{_mandir}/man8/faxsend.8c%{ext_man}
%{_mandir}/man8/faxsetup.8c%{ext_man}
%{_mandir}/man8/faxstate.8c%{ext_man}
%{_mandir}/man8/faxwatch.8c%{ext_man}
%{_mandir}/man8/hfaxd.8c%{ext_man}
%{_mandir}/man8/jobcontrol.8c%{ext_man}
%{_mandir}/man8/mkcover.8c%{ext_man}
%{_mandir}/man8/notify.8c%{ext_man}
%{_mandir}/man8/pagesend.8c%{ext_man}
%{_mandir}/man8/pollrcvd.8c%{ext_man}
%{_mandir}/man8/pdf2fax.8c%{ext_man}
%{_mandir}/man8/ps2fax.8c%{ext_man}
%{_mandir}/man8/recvstats.8c%{ext_man}
%{_mandir}/man8/tagtest.8c%{ext_man}
%{_mandir}/man8/tiff2fax.8c%{ext_man}
%{_mandir}/man8/tiffcheck.8c%{ext_man}
%{_mandir}/man8/tsitest.8c%{ext_man}
%{_mandir}/man8/wedged.8c%{ext_man}
%{_mandir}/man8/xferfaxstats.8c%{ext_man}
%{_mandir}/man8/faxfetch.8c%{ext_man}
%{_mandir}/man8/faxmsg.8c%{ext_man}
%{_mandir}/man8/faxsetup.linux.8c%{ext_man}
%{_mandir}/man8/hylafax.8c%{ext_man}
%{_mandir}/man8/lockname.8c%{ext_man}
%{_mandir}/man8/ondelay.8c%{ext_man}
%{_mandir}/man8/probemodem.8c%{ext_man}
%{_mandir}/man8/typetest.8c%{ext_man}
%{_mandir}/man1/textfmt.1%{ext_man}
%dir %{_sysconfdir}/hylafax
%dir %{_sysconfdir}/hylafax/faxmail
%dir %{_sysconfdir}/hylafax/faxmail/application
%dir %{_sysconfdir}/hylafax/faxmail/image
%config(noreplace) %{_sysconfdir}/hylafax/hfaxd.conf
%dir %{faxspool}/config
%dir %{faxspool}/dev
%{faxspool}/config/*
%{faxspool}/bin/dict/*
%{faxspool}/bin/genfontmap.ps
%{faxspool}/bin/auto-rotate.ps
%{faxspool}%{_sysconfdir}/dpsprinter.ps
%{faxspool}%{_sysconfdir}/cover.templ
%{faxspool}%{_sysconfdir}/lutRS18.pcf
%{faxspool}%{_sysconfdir}/LiberationSans-25.pcf
%config(noreplace) %{faxspool}%{_sysconfdir}/dialrules*
%defattr(755,root,root,-)
%config(noreplace) %{_sysconfdir}/cron.daily/hylafax
%config(noreplace) %{_sysconfdir}/cron.hourly/hylafax
%{_sbindir}/choptest
%{_sbindir}/cqtest
%{_sbindir}/dialtest
%{_sbindir}/faxabort
%{_sbindir}/faxaddmodem
%{_sbindir}/faxadduser
%{_sbindir}/faxanswer
%{_sbindir}/faxconfig
%{_sbindir}/faxcron
%{_sbindir}/faxdeluser
%{_sbindir}/faxinfo
%{_sbindir}/faxlock
%{_sbindir}/faxmodem
%{_sbindir}/faxmsg
%{_sbindir}/faxq
%{_sbindir}/faxqclean
%{_sbindir}/faxquit
%{_sbindir}/faxsetup
%{_sbindir}/faxsetup.linux
%{_sbindir}/faxstate
%{_sbindir}/faxwatch
%{_sbindir}/probemodem
%{_sbindir}/recvstats
%{_sbindir}/tagtest
%{_sbindir}/tiffcheck
%{_sbindir}/tsitest
%{_sbindir}/typetest
%{_sbindir}/xferfaxstats
%{_sbindir}/faxfetch
%{_sbindir}/faxgetty
%{_sbindir}/faxsend
%{_sbindir}/hfaxd
%{_sbindir}/hylafax
%{_sbindir}/lockname
%{_sbindir}/ondelay
%{_sbindir}/pagesend
%{_sbindir}/textfmt
%{faxspool}/bin/archive
%{faxspool}/bin/common-functions
%{faxspool}/bin/dictionary
%{faxspool}/bin/faxrcvd
%{faxspool}/bin/mkcover
%{faxspool}/bin/notify
%{faxspool}/bin/pcl2fax
%{faxspool}/bin/pdf2fax.gs
%{faxspool}/bin/pollrcvd
%{faxspool}/bin/ps2fax.gs
%{faxspool}/bin/qp-encode.awk
%{faxspool}/bin/rfc2047-encode.awk
%{faxspool}/bin/tiff2fax
%{faxspool}/bin/tiff2pdf
%{faxspool}/bin/wedged
%{_sysconfdir}/hylafax/faxmail/application/pdf
%{_sysconfdir}/hylafax/faxmail/application/octet-stream
%{_sysconfdir}/hylafax/faxmail/application/binary
%{_sysconfdir}/hylafax/faxmail/image/tiff
%defattr(-,uucp,uucp,-)
%dir %{faxspool}
%dir %{faxspool}/bin
%dir %{faxspool}/bin/dict
%dir %{faxspool}/client
%dir %{faxspool}/etc
%dir %{faxspool}/info
%dir %{faxspool}/log
%dir %{faxspool}/recvq
%dir %{faxspool}/status
%config(noreplace) %{faxspool}%{_sysconfdir}/xferfaxlog
%attr(700,uucp,uucp) %dir %{faxspool}/docq
%attr(700,uucp,uucp) %dir %{faxspool}/doneq
%attr(700,uucp,uucp) %dir %{faxspool}/archive
%attr(700,uucp,uucp) %dir %{faxspool}/sendq
%attr(700,uucp,uucp) %dir %{faxspool}/tmp
%attr(700,uucp,uucp) %dir %{faxspool}/pollq
%defattr(600,uucp,uucp,-)
%config(noreplace) %{faxspool}%{_sysconfdir}/hosts.hfaxd

%files -n libfaxutil%{lib_version}
%{_libdir}/libfaxutil*

%files -n hylafax+-client
%config(noreplace) %{_sysconfdir}/hylafax/faxcover.ps
%config(noreplace) %{_sysconfdir}/hylafax/faxmail.ps
%config(noreplace) %{_sysconfdir}/hylafax/pagesizes
%config(noreplace) %{_sysconfdir}/hylafax/typerules
%{_bindir}/faxalter
%{_bindir}/faxcover
%{_bindir}/faxmail
%{_bindir}/faxrm
%{_bindir}/faxstat
%{_bindir}/sendfax
%{_bindir}/sendpage
%{_sbindir}/edit-faxcover
%{_mandir}/man1/edit-faxcover.1%{ext_man}
%{_mandir}/man1/faxalter.1%{ext_man}
%{_mandir}/man1/faxcover.1%{ext_man}
%{_mandir}/man1/faxmail.1%{ext_man}
%{_mandir}/man1/faxrm.1%{ext_man}
%{_mandir}/man1/faxstat.1%{ext_man}
%{_mandir}/man1/hylafax-client.1%{ext_man}
%{_mandir}/man1/sendfax.1%{ext_man}
%{_mandir}/man1/sendpage.1%{ext_man}
%{_mandir}/man1/sgi2fax.1%{ext_man}

%changelog
* Wed May  9 2018 axel.braun@gmx.de
- boo#1091476: faxq must always run as real user root
* Sun Mar  4 2018 jengelh@inai.de
- Remove uucp user creation for pre-1500: aaa_base provides
  this user/group already.
* Wed Feb 21 2018 axel.braun@gmx.de
- create user/group uucp
  adapt services to use uucp
  boo#1081899
* Sat Nov  4 2017 axel.braun@gmx.de
- bnc1052195 localized Email notification chops german Umlauts
  correction in bin/notify common_functions dictionary
  * notification.diff
* Fri Jul 21 2017 tchvatal@suse.com
- Drop hylafax+_rh.init
- Drop conditionals for distros we never build against in OBS
- Switch to LCMS2
- Add jbikgit-devel dependency so it is detected by configure
* Mon Apr  3 2017 axel.braun@gmx.de
- hylafax+ 5.5.9
  * fix a handful of compiler warnings for gcc v7 (13, 17 Feb 2017)
  * fix job rescheduling if the proxy connection attempt fails (13 Jul 2016)
  * increase the maximum number of triggers from 1024 to 4096 (13 Jul 2016)
  * eliminate faxq job priority "bounding" (13 Jul 2016)
  * attempt to detect premature non-ECM Phase C carrier loss (15 Jun 2016)
  * add missing recvq error message indications (6 May 2016)
  * fix tagtest support for multi-strip images (25 Mar 2016)
  * enhance textfmt wrapping to occur on word boundaries (24 Feb 2016)
* Sun Apr  3 2016 axel.braun@gmx.de
- hylafax+ 5.5.8
  * stop using mktemp() (5 Feb 2016)
  * fix LDAP authentication broken in 5.5.4 (24-26 Jan 2016)
  * reset senderinfo properly when receiving faxes (22 Jan 2016)
  * cope with V.21 HDLC carrier loss following +FRH:3 better (22, 26 Jan 2016)
  * increase the time Class1SwitchingCmd will wait for a response (14 Jan 2016)
  * undo faulty/incorrect previous "fix" to ntries/npages (13 Jan 2016)
  * fix short blocking problems in reading from the device (12 Jan 2016)
* Sun Feb  7 2016 axel.braun@gmx.de
- Fixed file list entry for faxcron
* Sat Feb  6 2016 axel.braun@gmx.de
- put texfmt manpage into the right package
* Tue Dec 29 2015 axel.braun@gmx.de
- hylafax 5.5.7
  * fix ntries counter to apply to pages instead of documents (5 Dec 2015)
  * reject jobs rejected by the proxy (18-19 Nov 2015)
  * add RewriteFaxName and RewriteFaxNumber jobcontrol features (14 Nov 2015)
  * improve Chinese translation (7 Oct 2015)
  * make faxsetup fix blind references in Fontmap.HylaFAX (3 Oct 2015)
  * use the remote time on proxy job submisisons (17 Sep 2015)
  * create more-secure hosts.hfaxd passwords by default (28 Aug 2015)
  * add admin login feature for faxstat (27 Aug 2015)
  * add ProxyJobTag jobcontrol feature (26 Aug 2015)
  * fix grevious calculation problem with Class1RestrictPoorSenders and
  Class1RestrictPoorDestinations (20 Aug 2015)
  * add application/binary MIMEConverter (17 Jul 2015)
  * fix DynamicConfig for Class 1 modem data format support (15 Jul 2015)
  * fix crash in tagline imaging due to glyph ascent (23 Jun 2015)
  * stop messing with the FIFO during installs and uninstalls (16 Jun 2015)
  * avoid conflicts with a TTY environment variable (15 Jun 2015)
  * fix dataTimeout esp for modems with large buffers in non-ECM (22 May 2015)
  * fix dataTimeout primarily affecting 7200 bps ECM sending (15 May 2015)
* Wed Dec 16 2015 pth@suse.de
- the proper name of the symlink is rchylafax.
* Mon Dec 14 2015 pth@suse.de
- Guard the inclusion of rchylafax+.
* Fri Dec 11 2015 pth@suse.de
- Only run cron jobs if hylafax is configured (boo#958150)
- Clean up the spec file a bit.
- Fix build.
- Export CFLAGS and CXXFLAGS so that the flags are imported by
  configure.
- Use 'make -j1' to prevent parallel building.
- post and postun sections are always need.
* Tue Jul 14 2015 axel.braun@gmx.de
- release 5.5.6
  * add typerules suggestion for PNG conversion (19 Mar 2015)
  * support more than 256 pages in Class 1 ECM (26 Feb 2015)
  * cope with application/pdf being encoded with quoted-printable
  in faxmail (13 Feb 2015)
  * fix npages and totpages recording in sendq when proxied (31 Jan 2015)
  * fix EOF reading fault on badly-formatted MIME in faxmail (12 Jan 2015)
  * fix hi-res tagline imaging on 64-bit systems (10 Dec 2014)
  * add support for seqf.increment files to indicate seqf
  incrementation (14 Nov 2014)
  * add support to faxmail to decode long-wrapped base64 (11, 14-15 Oct 2014)
  * fix proxy setting of null taglines (16 Sep 2014)
  * fix ModemWaitForConnect configuration setting (16 Sep 2014)
  * add debug messages for the attempt to locate a suitable modem
  for jobs (12 Aug 2014)
  * fix missed data type for libtiff v4 (31 Jul, 11 Aug 2014)
  * fix faxsend segfault caused by an empty TagLine field introduced in
  alignment features added in 5.5.5 (25 Jul 2014)
  * pass job priority to the proxy server (21 Jul 2014)
  * add JobHostID feature (16, 29-31 Jul 2014)
  * fix instances where a NULL return of crypt() is ignored (13 Jul 2014)
  * improve support for utmpx on BSD (10 Jul 2014)
  * apply some downstream patches from FreeBSD ports (10 Jul 2014)
  * use ps2write in faxmail pdf converter if pswrite is missing (6 Jul 2014)
  * modify FIFO usage and remove CONFIG_FIFOBUG and CONFIG_OPENFIFO (5 Jul 2014)
* Mon May  4 2015 axel.braun@gmx.de
- bnc#922402 update overwrites send-only settings to systemd config
* Thu Mar 12 2015 hpj@urpla.net
- fix standalone hylafax+-client fallout
* Thu Mar 12 2015 pth@suse.de
- Move libfaxutil into its own sub package (bnc#922017).
* Tue Feb 24 2015 axel.braun@gmx.de
- fix for bnc#856906 also for client package
* Wed Feb 18 2015 axel.braun@gmx.de
- dependency on tiff added
- build dependency on ghostscript
* Thu Feb 12 2015 axel.braun@gmx.de
- fix for bnc#856906
* Sun Dec 14 2014 axel.braun@gmx.de
- corrected typo (path) in README.SUSE
* Fri Nov 14 2014 axel.braun@gmx.de
-fix inclusion of initscript for SysV startup
* Wed Nov 12 2014 axel.braun@gmx.de
- Adapt README.SUSE to renamed service files
* Thu Nov  6 2014 pth@suse.de
- Rename README.SuSE to README.SUSE
- Remove systemd from service file names and adapt contents
  accordingly.
- Fix suse_version tests.
* Wed Nov  5 2014 pth@suse.de
- Fix spec file
* Tue Nov  4 2014 pth@suse.de
- Use macros for service handling
* Mon Nov  3 2014 pth@suse.de
- Include tarball.
- License is BSD-3-Clause.
- Set obsoletes and provides for hylafax-client.
* Mon Oct 27 2014 pth@suse.de
- Make spec a bit more readable.
* Sat Oct 18 2014 axel.braun@gmx.de
- added documentation for send-only environment
* Tue Oct 14 2014 axel.braun@gmx.de
- README.suse added (systemd-setup for hylafax)
* Mon Oct 13 2014 axel.braun@gmx.de
- added systemd-example for faxgetty
* Thu Nov 28 2013 axel.braun@gmx.de
- Split out hylafax client
* Tue Oct 29 2013 axel.braun@gmx.de
- New release 5.5.4
* Tue Jan 15 2013 Axel Braun <axel.braun@gmx.de>
- adapt spec for use with open Build service
* Tue Dec 11 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-6
- make dependency on systemd-units and system instead of /bin/systemctl
- modify systemd scriptlets
- use defattr to accomodate correct permissions for mock builds
* Sat Dec  8 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-5
- remove defattr from files
- rename patches and all but Source0 to hylafax+
- remove config(noreplace) from FIFO
- add /bin/systemctl build dependency for Fedora > 16
* Mon Dec  3 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-4
- add missing man pages
* Sun Nov  4 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-3
- spec optimizations
- clarify linkage in libfaxserver
- add systemd support
* Thu Nov  1 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-2
- change package name to hylafax+
- add Provides: hylafax
* Sat Oct 13 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.2-1
- update to 5.5.2
* Thu Jan 12 2012 Lee Howard <faxguy@howardsilvan.com> - 5.5.1-1
- update to 5.5.1
* Sat Dec 18 2010 Lee Howard <faxguy@howardsilvan.com> - 5.5.0-1
- update to 5.5.0
* Wed Oct 13 2010 Lee Howard <faxguy@howardsilvan.com> - 5.4.3-1
- update to 5.4.3
* Sun May  2 2010 Lee Howard <faxguy@howardsilvan.com> - 5.4.2-1
- update to 5.4.2
* Mon Feb 22 2010 Lee Howard <faxguy@howardsilvan.com> - 5.4.1-1
- update to 5.4.1
* Wed Dec 23 2009 Lee Howard <faxguy@howardsilvan.com> - 5.4.0-1
- update to 5.4.0
- add lcms-devel build dependency
* Sun Oct 25 2009 Lee Howard <faxguy@howardsilvan.com> - 5.3.0-1
- update to 5.3.0
* Sat Feb 28 2009 Lee Howard <faxguy@howardsilvan.com> - 5.2.9-1
- update to 5.2.9
- remove "Provides: hylafax"
* Sun Dec 21 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.8-1
- update to 5.2.8
* Mon Apr 28 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.4-3
- openldap-devel and pam-devel build dependencies
* Wed Apr 23 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.4-1
- update to 5.2.4
* Sat Mar 29 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.3-1
- update to 5.2.3
* Fri Jan 18 2008 Lee Howard <faxguy@howardsilvan.com> - 5.2.2-1
- make licensing BSD, initscript is not config, remove libtiff dependency
* Thu Nov  8 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.11-1
- add libtiff dependency
* Thu Aug  2 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.7-1
- update to 5.1.7
* Sat Jul 14 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.6-1
- accomodate MIMEConverter script location change
* Fri Mar 23 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.2-1
- made faxq's FIFO "noreplace" to keep upgrades from messing up a running faxq
* Thu Mar  8 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.1-1
- update to 5.1.1
* Thu Feb 22 2007 Lee Howard <faxguy@howardsilvan.com> - 5.1.0-1
- update to 5.1.0
* Thu Jan 11 2007 Lee Howard <faxguy@howardsilvan.com> - 5.0.4-1
- update to 5.0.4
* Mon Jan  1 2007 Lee Howard <faxguy@howardsilvan.com> - 5.0.3-1
- update to 5.0.3
* Wed Dec 13 2006 Lee Howard <faxguy@howardsilvan.com> - 5.0.2-1
- update to 5.0.2
* Wed Nov  1 2006 Lee Howard <faxguy@howardsilvan.com> - 5.0.0-1
- update to 5.0.0
- disable build of debuginfo package
- change ownership of config and dev to root,root
- move changelog to the end of the spec file
* Mon Sep 18 2006 Lee Howard <faxguy@howardsilvan.com> - 4.3.0.11-1
- update to 4.3.0.1
* Tue Apr 11 2006 Lee Howard <faxguy@howardsilvan.com> - 4.2.5.6-1
- update to 4.2.5.6
* Tue Apr 11 2006 Lee Howard <faxguy@howardsilvan.com> - 4.2.5.5-1
- initial 4.2.5.5 build
